@@ -183,7 +183,7 @@ class WheelRepair:
             return hash, size
 
     @staticmethod
-    def _hashfile(afile: typing.BinaryIO, blocksize: int = 65536, length: int = 8) -> str:
+    def _hashfile(afile: typing.BinaryIO, blocksize: int = 65536, length: int = 32) -> str:
         """Hash the contents of an open file handle with SHA256. Return the
         first length characters of the hash."""
         hasher = hashlib.sha256()
@@ -632,4 +632,4 @@ class WheelRepair:
                 if self._verbose >= 1:
                     print(f'adding {relpath}')
                 whl_file.write(file_path, relpath)
-        print(f'fixed wheel written to {os.path.abspath(whl_dest_path)}\n')
+        print(f'fixed wheel written to {os.path.abspath(whl_dest_path)}')
